@@ -412,14 +412,14 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             default=None,
             nargs="*",
             metavar="WHEN",
-            help='target date for the meeting, for example "in two weeks" [default: now]',
+            help='target date for the meeting, for example "in two weeks", default: now',
         )
         group.add_argument(
             "-t",
             "--timezones",
             nargs="+",
             default=[],
-            help="time zones to show [default: current time zone]",
+            help="time zones to show, default: current time zone",
         )
         group.add_argument(
             "-s",
@@ -427,7 +427,7 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             default=9,
             type=int,
             metavar="HOUR",
-            help="start of working day, in hours [default: %(default)s]",
+            help="start of working day, in hours, default: %(default)s",
         )
         group.add_argument(
             "-e",
@@ -435,7 +435,7 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             default=17,
             type=int,
             metavar="HOUR",
-            help="end of working day, in hours [default: %(default)s]",
+            help="end of working day, in hours, default: %(default)s",
         )
         group = self.add_argument_group("display options")
         group.add_argument(
@@ -446,42 +446,49 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             default=sys.stdout.isatty()
             and "NO_COLOR" not in os.environ
             and "UNDERTIME_NO_COLOR" not in os.environ,
-            help="show colors [default: %(default)s]",
+            help="show colors, default: %(default)s",
         )
         group.add_argument(
             "--no-default-zone",
             "--default-zone",
             action=NegateAction,
             dest="default_zone",
-            help="show current time zone first [default: %(default)s]",
+            help="show current time zone first, default: %(default)s",
         )
         group.add_argument(
             "--no-unique",
             "--unique",
             action=NegateAction,
             dest="unique",
-            help="deduplicate time zone offsets [default: %(default)s]",
+            help="deduplicate time zone offsets, default: %(default)s",
+        )
+        group.add_argument(
+            "--no-sort",
+            "--sort",
+            action=NegateAction,
+            dest="sort",
+            help="sort time zone offsets, default: %(default)s",
         )
         group.add_argument(
             "--no-overlap",
             "--overlap",
             action=NegateAction,
             dest="overlap",
-            help="show zones overlap [default: %(default)s]",
+            help="show zones overlap, default: %(default)s",
         )
         group.add_argument(
             "--overlap-min",
             default=0,
             type=int,
             metavar="N",
-            help="minimum overlap between zones [default: %(default)s]",
+            help="minimum overlap between zones, default: %(default)s",
         )
         group.add_argument(
             "--truncate",
             "--no-truncate",
             dest="truncate",
             action=NegateAction,
-            help="short column headers [default: %(default)s]",
+            help="short column headers, default: %(default)s",
         )
         # backwards-compatibility for config file and scripts
         group.add_argument(
@@ -496,26 +503,27 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             "--table",
             dest="table",
             action=NegateAction,
-            help="hide/show the actual table [default: %(default)s]",
+            help="hide/show the actual table, default: %(default)s",
         )
         group.add_argument(
             "--no-time-details",
             "--time-details",
             dest="time_details",
             action=NegateAction,
-            help="show/hide trailing time details like UTC, local, and equivalent times [default: %(default)s]",
-        )
-        group.add_argument(
-            "--all-formats",
-            action="store_true",
-            help="show a sample of *all* table formats",
+            help="show/hide trailing time details like UTC, local, and equivalent times, default: %(default)s",
         )
         group.add_argument(
             "-f",
             "--format",
             default="fancy_grid_nogap",
+            metavar="FORMAT",
             choices=tabulate.tabulate_formats + ["fancy_grid_nogap"],
-            help="output format (%(default)s)",
+            help="output format, default: %(default)s",
+        )
+        group.add_argument(
+            "--all-formats",
+            action="store_true",
+            help="show all table formats, implies --table --no-time-details",
         )
         # START HACK
         #
@@ -527,7 +535,7 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             "--config",
             action=YamlConfigAction,
             default=self.default_config(),
-            help="configuration file [default: first of %s]"
+            help="configuration file, default: first of %s"
             % " ".join(self.default_config()),
         )
         self.add_argument(
@@ -589,6 +597,9 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             self.error("date specified as an argument an option, aborting")
         if ns.datelist and not ns.date:
             ns.date = " ".join(ns.datelist)
+        if ns.all_formats:
+            ns.table = True
+            ns.time_details = False
         if not ns.time_details and not ns.table:
             logging.warning(
                 "select --table or --time-details otherwise undertime does nothing, falling back to --time-details"
@@ -880,6 +891,13 @@ def flush_logging_handlers():
         handler.flush()
 
 
+def print_all_zones_with_offsets():
+    """print all zones with offsets"""
+    for zone in pytz.all_timezones:
+        offset = pytz.timezone(zone).utcoffset(datetime.datetime.now())
+        print(zone, offset.total_seconds() / (60 * 60))
+
+
 def main(args):
     """Main entry point.
 
@@ -888,8 +906,7 @@ def main(args):
     first one of those caused me problems at that time and I wanted to
     have a good handle on it."""
     if args.list_zones:
-        print("\n".join(pytz.all_timezones))
-        return
+        return print_all_zones_with_offsets()
 
     if not args.colors:
         global fmt_time
@@ -921,6 +938,11 @@ def main(args):
         logging.error("No valid time zone found.")
         sys.exit(1)
 
+    if args.sort:
+        timezones = sorted(
+            timezones, key=lambda x: x.utcoffset(then_utc.replace(tzinfo=None))
+        )
+
     if args.table:
         rows = compute_table(
             then_local,
@@ -960,7 +982,9 @@ def main(args):
             times.append(ts)
         print("UTC time: {}".format(then_utc))
         print("local time: {}".format(then_local))
-        print("equivalent to: " + ", ".join(times))
+        print("equivalent to:")
+        for t in times:
+            print("-", t)
 
 
 def guess_zone(zone):
